Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(207)

Unified Diff: content/public/browser/web_contents_delegate.h

Issue 2400673003: Remove SSLStatus::security_style member and content::SecurityStyle (Closed)
Patch Set: more curly braces Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/browser/ssl_status.cc ('k') | content/public/browser/web_contents_delegate.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/web_contents_delegate.h
diff --git a/content/public/browser/web_contents_delegate.h b/content/public/browser/web_contents_delegate.h
index e266c6c8f368830e16b69d2fd6a8c3e18aa64882..d6e7139fa7a64a8c6294010f0195e655351cab08 100644
--- a/content/public/browser/web_contents_delegate.h
+++ b/content/public/browser/web_contents_delegate.h
@@ -17,10 +17,10 @@
#include "content/public/browser/bluetooth_chooser.h"
#include "content/public/browser/invalidate_type.h"
#include "content/public/common/media_stream_request.h"
-#include "content/public/common/security_style.h"
#include "content/public/common/window_container_type.h"
#include "third_party/WebKit/public/platform/WebDisplayMode.h"
#include "third_party/WebKit/public/platform/WebDragOperation.h"
+#include "third_party/WebKit/public/platform/WebSecurityStyle.h"
#include "third_party/skia/include/core/SkColor.h"
#include "ui/base/window_open_disposition.h"
#include "ui/gfx/geometry/rect_f.h"
@@ -520,8 +520,8 @@ class CONTENT_EXPORT WebContentsDelegate {
// Can be overridden by a delegate to return the security style of the
// given |web_contents|, populating |security_style_explanations| to
// explain why the SecurityStyle was downgraded. Returns
- // SECURITY_STYLE_UNKNOWN if not overriden.
- virtual SecurityStyle GetSecurityStyle(
+ // WebSecurityStyleUnknown if not overriden.
+ virtual blink::WebSecurityStyle GetSecurityStyle(
WebContents* web_contents,
SecurityStyleExplanations* security_style_explanations);
« no previous file with comments | « content/public/browser/ssl_status.cc ('k') | content/public/browser/web_contents_delegate.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698